InsightFace

Struct InsightFace 

pub struct InsightFace { /* private fields */ }
InsightFace is a struct which handle the internal pointers to compare two faces and returns the cosine value

Implementations

Source

impl InsightFace

pub fn new<S: AsRef<str>>( model: S, chunk_size: Option<usize>, ) -> Result<Self, Box<dyn Error>>

Create a new InsightFace handler. It needs to be only call once as it build a model. Therefore it’s recommended to use it within an Arc<Mutex<InsightFace>> to ensure thread safety. Chunk size is used in order to split the image data into smaller chunks for processing.

Arguments
  • model - S
  • chunk_size - u8
Examples
use std::sync::Arc;
use std::sync::Mutex;
use baklava::InsightFace;

let insight_face = Arc::new(Mutex::new(InsightFace::new("./Megatron", None).unwrap()));
pub fn prepare_images<S: AsRef<str> + Clone + Send + Sync + Copy>( &mut self, sources: &[S], ) -> Result<&mut Self, Box<dyn Error>>

Prepare a slice of a images to be compared toward the target

Arguments
  • sources - &[S]
pub fn prepare_target_image<S: AsRef<str>>( &mut self, target_img_path: S, ) -> Result<&mut Self, Box<dyn Error>>

Prepare the target image that will be compared against the sources images

Arguments
  • target_img_path - S
pub fn compare_images( &self, methodology: Methodology, ) -> Result<(f32, f64), Box<dyn Error>>

Compare the images and return the cosine similary which can range from 1 to -1

Arguments
  • methodology - Methodology
pub fn is_similar(cosine: f32, threshold: Option<f64>) -> bool

Return whether the two faces are similar based on the cosine

Arguments
  • cosine - f32
  • threshold - Option<f64>